View source: R/voting_methods.R
| sav | R Documentation |
Satisfaction Approval Voting (SAV) ranks candidates by normalizing approval scores based on the size of each voter's approval set. Voters who approve more candidates contribute a lesser score to the individual approved candidates.
This function uses an internal C++ implementation for efficient computation.
sav(
voters,
candidates,
weights = NULL,
committee_size = NULL,
borda_score = TRUE,
check = FALSE
)
voters |
( |
candidates |
( |
weights |
( |
committee_size |
( |
borda_score |
( |
check |
( |
A data.frame with columns:
"candidate": Candidate names.
"score": Satisfaction scores.
"norm_score": Normalized scores, scaled to the range [0,1].
"borda_score": Borda scores for method-agnostic comparison, ranging in
[0,1], where the top candidate receives a score of 1 and the lowest-ranked
candidate receives a score of 0, based on the total number of candidates.
Candidates are ordered by decreasing "score".
Other voting methods:
av(),
seq_pav(),
seq_phragmen()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.